import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * A collection of missiles and a launch key
 *
 * @author Xevinaly
 * @version v0.0.1
 */
public class Bunker extends Actor
{
    private int missiles = 10;
    private int canfire = -4;
    private String key;
    private Cursor target;
    private Color contrailcolor;
    private Generator generator;
    private FluidActor message;
    private Rocket[] missileimages = new Rocket[10];
    private int[][] coordinates = new int[][]{{0, -10}, {-5, -5}, {5, -5}, {-10, 0}, {0, 0}, {10, 0}, {-15, 5}, {-5, 5}, {5, 5}, {15, 5}};

    /**
     * Constructor - makes the bunker invisible
     *
     * @param setkey  the key to be pressed to fire
     * @param cursor  the curser which aims the missiles
     */
    public Bunker(String setkey, Cursor cursor, Generator passedgenerator, Color levelcolor)
    {
        GreenfootImage img = new GreenfootImage(1, 1);
        img.setColor(new Color(0, 0, 0, 0));
        img.fill();
        setImage(img);
        key = setkey;
        target = cursor;
        generator = passedgenerator;
        contrailcolor = levelcolor;
    }

    /**
     * addedToWorld - sets up initial world properties
     *
     * @param world  the world to add the actor to
     */
     @Override
    public void addedToWorld(World world)
    {
        setup();
    }

    /**
     * Act - do whatever the Bunker wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act()
    {
        if(getOneIntersectingObject(Explosion.class) != null)
        {
            for(int i = 0; i < 10; i++)
            {
                try
                {
                    missileimages[i].selfdestruct();
                }
                catch(Exception e){}
            }
            missiles = 0;
        }
        if(Greenfoot.isKeyDown(key) && canfire > 0 && missiles > 0  && !generator.getNewLevel())
            fireMissile();
        canfire++;
        if(missiles == 0)
        {
            try
            {
                message.setImage(new FluidImage("images/Out.txt", 30, 15));
            }
            catch(Exception e)
            {
                message = new FluidActor("images/Out.txt", 30, 15);
                getWorld().addObject(message, getX(), getY() + 25);
            }
        }
    }

    /**
     * setup - sets up the rocket images
     */
    private void setup()
    {
        for(int i = 0; i < 10; i++)
        {
            missileimages[i] = new Rocket("images/Rocket.txt", 6, 9);
            getWorld().addObject(missileimages[i], getX() + coordinates[i][0], getY() + coordinates[i][1]);
        }
    }

    /**
     * fireMissile - fires a missile
     */
    private void fireMissile()
    {
        missiles--;
        getWorld().removeObject(missileimages[missiles]);
        canfire = -12;
        getWorld().addObject(new Missile(generator, generator.createFriendlyContrail(getX(), getY(), target.getY(), target.getX()), 1000, contrailcolor, false, 12), getX(), getY() - 15);
        if(missiles == 3)
        {
            message = new FluidActor("images/Low.txt", 30, 15);
            getWorld().addObject(message, getX(), getY() + 25);
        }
        if(missiles == 0)
            message.setImage(new FluidImage("images/Out.txt", 30, 15));
    }

    /**
     * getNextMissile - moves the next missile image
     *
     * @param x  the x position to move to
     * @param y  the y position to move to
     */
    public void getNextMissile(int x, int y)
    {
        missiles--;
        missileimages[missiles].setLocation(x, y);
    }

    /**
     * hasMissiles - returns if there are more missiles
     *
     * @return  if there are more missiles
     */
    public boolean hasMissiles()
    {
        if(missiles > 0)
            return true;
        return false;
    }

    /**
     * remainingMissiles - returns the number of rocket images left
     *
     * @return  the number of rockets left
     */
    public int remainingMissiles()
    {
        return missiles;
    }

    /**
     * selfDestruct - destroys the bunker
     */
    public void selfDestruct()
    {
        for(int i = 0; i < 10; i++)
        {
            try
            {
                getWorld().removeObject(missileimages[i]);
            }catch(Exception e){}
        }
        getWorld().removeObject(message);
        getWorld().removeObject(this);
    }

    /**
     * A private class that represents the rocket images
     *
     * @author Xevinaly
     * @version v0.0.1
     */
    private class Rocket extends FluidActor
    {
        /**
         * Constructor - sets the image
         *
         * @param imagefile the file to use with the FluidImage
         * @param height    the image height
         * @param width     the image width
         */
        public Rocket(String imagefile, int height, int width)
        {
            super(imagefile, height, width);
        }

        /**
         * Act - do whatever the Missile wants to do. This method is called whenever
         * the 'Act' or 'Run' button gets pressed in the environment.
         */
        public void act()
        {
            if(getOneIntersectingObject(Explosion.class) != null)
            {
                Explosion explosion = (Explosion)getOneIntersectingObject(Explosion.class);
                if(getImage().compareHitboxs(explosion.getHitbox(),explosion.getX(), explosion.getY(), getX(), getY()))
                {
                    getWorld().addObject(new Explosion(), getX(), getY());
                    getWorld().removeObject(this);
                }
            }
        }

        /**
         * Act - do whatever the Missile wants to do. This method is called whenever
         * the 'Act' or 'Run' button gets pressed in the environment.
         */
        public void selfdestruct()
        {
            getWorld().addObject(new Explosion(), getX(), getY());
            getWorld().removeObject(this);
        }
    }
}
