import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;
import java.io.*;

/**
 * The cities that you need to protect
 *
 * @author Xevinaly
 * @version v0.0.3
 */
public class City extends FluidActor
{
    private boolean destroyed = false, moved = false;

    /**
     * Constructor - sets the background image
     */
    public City()
    {
        super("images/City.txt", 30, 15);
    }

    /**
     * Act - do whatever the City wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act()
    {
        if(getOneIntersectingObject(Explosion.class) != null)
        {
            Explosion explosion = (Explosion)getOneIntersectingObject(Explosion.class);
            if(explosion != null && getImage().compareHitboxs(explosion.getHitbox(), explosion.getX(), explosion.getY(), getX(), getY()))
            {
                destroyed = true;
                getImage().colorHitboxOverlap(explosion.getImage().getHitbox(), explosion.getX(), explosion.getY(), getX(), getY(), 2);
            }
        }
    }

    /**
     * getDestroyed - returns whether the city has been destroyed
     *
     * @return  returns whether the city has been destroyed
     */
    public boolean getDestroyed()
    {
        return destroyed;
    }

    /**
     * getMoved - returns whether the city has been moved
     *
     * @return  returns whether the city has been moved
     */
    public boolean getMoved()
    {
        return moved;
    }

    /**
     * spawnMisslets - sets the city as moved
     */
    public void setMoved()
    {
        moved = true;
    }

    /**
     * colorChange - finds the color to change to
     *
     * @return  the color to change the city to when it is destroyed
     */
    public Color getColorChange()
    {
        int colorscheme = 0;
        try
        {
            FileReader input = new FileReader("Color_Scheme.txt");
            BufferedReader stream = new BufferedReader(input);
            colorscheme = Integer.parseInt(stream.readLine());
            stream.close();
            input.close();
        }
        catch(IOException e)
        {
            System.out.println("Error: Color_Scheme.txt not found");
        }
        switch((2 + colorscheme)%8)
        {
            case 0: return Color.WHITE;
            case 1: return Color.RED;
            case 2: return Color.YELLOW;
            case 3: return Color.BLUE;
            case 4: return Color.ORANGE;
            case 5: return Color.PINK;
            case 6: return Color.CYAN;
            case 7: return Color.MAGENTA;
            case 8: return Color.GREEN;
            default: return new Color(0, 0, 0, 0);
            }
    }
}
