import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;
import java.io.*;

/**
 * Replaces the world class since it became super shit in the last update and acts as a link to other
 * active classes as well as a way to quickly switch world states.
 *
 * @author Xevinaly
 * @version v0.0.6
 */
public class Control extends Actor
{
    private int controlID = 0;
    // World 0 - the animation screen
    private StartScreen startscreen = new StartScreen();
    // World 1 - the play screen
    private Generator generator = new Generator();

    /**
     * constructor - sets the image
     */
    public Control()
    {
        GreenfootImage img = new GreenfootImage(1, 1);
        img.setColor(new Color(0, 0, 0, 0));
        img.fill();
        setImage(img);
    }

    /**
     * addedToWorld - sets up initial world properties
     *
     * @param world  the world to add the actor to
     */
     @Override
    public void addedToWorld(World world)
    {
        try
        {
            FileWriter writer = new FileWriter("Color_Scheme.txt", false);
            writer.write("" + 0);
            writer.close();
        }
        catch(IOException e)
        {
            System.out.println("Error: Color_Scheme.txt not found");
        }
        render(controlID);
    }

    /**
     * Act - do whatever the Switcher wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act()
    {
        int compare = controlID;
        controlID = checkState(controlID);
        if(compare != controlID)
        {
            softReset(compare);
            if(controlID == 2)
                hardReset();
            render(controlID);
        }
    }

    /**
     * render - renders the specified world
     *
     * @param ID the world ID to render
     */
    public void render(int ID)
    {
        switch(ID)
        {
            case 0: getWorld().addObject(startscreen, 250, 225);
                    break;
            case 1: getWorld().addObject(generator, 250, 225);
                    break;
        }
    }

    /**
     * checkState - checks input from the current world
     *
     * @param ID the world ID to check input from
     */
    public int checkState(int ID)
    {
        switch(ID)
        {
            case 0: return startscreen.checkState();
            case 1: return generator.checkState();
        }
        return ID;
    }

    /**
     * softReset - resets all areas except those of the world ID and static areas
     *
     * @param ID the world ID to avoid reseting
     */
    public void softReset(int ID)
    {
        switch(ID)
        {
            case 0: getWorld().removeObject(startscreen);
                    startscreen = new StartScreen();
                    break;
            case 1: generator.clear();
                    generator.resetColorScheme();
                    getWorld().removeObject(generator);
                    break;
        }
    }

    /**
     * hardReset - deletes persistent data
     */
    public void hardReset()
    {
        startscreen = new StartScreen();
        generator = new Generator();
    }
}
