import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.awt.Color;

/**
 * The missiles which are shot at you and shot by you
 *
 * @author Xevinaly
 * @version v0.1.8
 */
public class Missile extends FluidActor
{
    private int splinterheight, time = 0, speed;
    private int[][] contrailcoordinates;
    private Generator generator;
    private boolean end = false, detonation = false, splinterable, points = true;
    private Color contrailcolor;

    /**
     * Constructor - sets the image
     *
     * @param generator    the generator which shows the contrail
     * @param contrail     a set of coordinates to move across
     * @param ymax         where the missile splinters
     * @param color        the color of the contrails
     * @param cansplinter  if the missile can splinter
     */
    public Missile(Generator passedgenerator, int[][] contrail, int ymax, Color color, boolean cansplinter, int pixels)
    {
        super("images/MissileHead.txt", 1, 1);
        generator = passedgenerator;
        contrailcoordinates = contrail;
        splinterheight = ymax;
        contrailcolor = color;
        splinterable = cansplinter;
        speed = pixels;
    }

    /**
     * Act - do whatever the Missile wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act()
    {
        try
        {
            for(int i = 0; i < speed; i++)
            {
                generator.getImage().setColorAt(contrailcoordinates[time][0], contrailcoordinates[time][1], contrailcolor);
                time++;
            }
            setLocation(contrailcoordinates[time][0], contrailcoordinates[time][1]);
        }
        catch(ArrayIndexOutOfBoundsException e)
        {
            end = true;
            detonation = true;
            points = false;
        }
        if(getOneIntersectingObject(Explosion.class) != null)
        {
            Explosion explosion = (Explosion)getOneIntersectingObject(Explosion.class);
            if(getImage().compareHitboxs(explosion.getHitbox(), explosion.getX(), explosion.getY(), getX(), getY()))
            {
                end = true;
                detonation = true;
                points = false;
                if(getY() < 382)
                  points = true;
            }
        }
        else if(getY() >= splinterheight)
        {
            generator.spawnMisslets(getY(), getX(), splinterable);
            end = true;
            points = false;
        }
        if(end)
        {
            if(detonation)
                getWorld().addObject(new Explosion(), getX(), getY());
            removeContrail();
            if(speed == 1 && points)
                generator.increaseScore(10);
            getWorld().removeObject(this);
        }
    }

    /**
     * removeContrail - removes the created contrail
     */
    public void removeContrail()
    {
        for(int i = 0; i < time; i++)
        {
            generator.getImage().setColorAt(contrailcoordinates[i][0], contrailcoordinates[i][1], new Color(0, 0, 0, 0));
        }
    }
}
