import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)
import java.util.Random;
import java.awt.Color;
import java.util.List;

/**
 * The start screen of the game which waits for input and then plays the intro animation and starts the game.
 *
 * @author Xevinaly
 * @version v0.0.1
 */
public class StartScreen extends FluidActor
{
    private boolean cutscene = false, screenover = false;
    private int timer = 0, messageposition = 49, currentmessageindex = 0;
    private FluidString message, alert;
    private Random rng = new Random();
    private String[] messages = new String[]{"Protect the west coast cities", "Extra life every 5000 points     ", "Watch out for compound missiles     ", "Use the a_ s_ and d keys to fire     ", "control the cursor with the arrow keys", "cities are 100 bonus points and unused missiles are 10 bonus points"};

    /**
     * Constructor - sets the image
     */
    public StartScreen()
    {
        super("images/Logo.txt", 210, 100);
        alert = new FluidString("Press space to start");
        message = new FluidString(" ");
    }

    /**
     * addedToWorld - sets up initial world properties
     *
     * @param world  the world to add the actor to
     */
     @Override
    public void addedToWorld(World world)
    {
      getWorld().addObject(alert, 250, 350);
      getWorld().addObject(message, 250, 440);
    }

    /**
     * Act - do whatever the Logo wants to do. This method is called whenever
     * the 'Act' or 'Run' button gets pressed in the environment.
     */
    public void act()
    {
        if(!cutscene)
        {
            if(timer%5 == 0)
                adjustMessage();
            if(timer%20 == 0)
                flashAlert();
            if(Greenfoot.isKeyDown("space"))
            {
                getWorld().removeObject(alert);
                getWorld().removeObject(message);
                cutscene = true;
                timer = 0;
            }
        }
        if(cutscene)
        {
            if(timer%10 == 0 && timer < 150)
                getWorld().addObject(new Explosion(), rng.nextInt(300) + 100, rng.nextInt(250) + 100);
            if(getOneIntersectingObject(Explosion.class) != null)
            {
                List explosions = getIntersectingObjects(Explosion.class);
                for(int i = 0; i < explosions.size(); i++)
                    getImage().destroyHitboxOverlap(((Explosion)explosions.get(i)).getImage().getHitbox(), ((Explosion)explosions.get(i)).getX(), ((Explosion)explosions.get(i)).getY(), getX(), getY());
            }
            if(timer >= 300)
              screenover = true;
        }
        timer++;
    }

    /**
     * adjustMessage - adjusts the current message to scroll across the screen
     */
    private void adjustMessage()
    {
        if(messageposition <= 0 - messages[currentmessageindex].length())
        {
            messageposition = 49;
            currentmessageindex++;
            if(currentmessageindex == messages.length)
                currentmessageindex = 0;
        }
        int index = 0;
        if(messageposition < 0)
            index = 0 - messageposition;
        String newmessage = "";
        for(int i = 0; i < 50; i++)
        {
            if(i >= messageposition && index < messages[currentmessageindex].length())
            {
                newmessage += messages[currentmessageindex].charAt(index) + "";
                index++;
            }
            else
                newmessage += " ";
        }
        getWorld().removeObject(message);
        message = new FluidString(newmessage);
        getWorld().addObject(message, 250, 440);
        messageposition--;
    }

    /**
     * flashAlert - causes the alrt to blink on and off
     */
    private void flashAlert()
    {
        if(timer%40 == 0)
            getWorld().removeObject(alert);
        else
            getWorld().addObject(alert, 250, 350);
    }

    /**
     * checkState - checks to see if the intro screen should switch to the play screen
     */
    public int checkState()
    {
        if(screenover)
            return 1;
        return 0;
    }
}
